#
# spec file for package lua-mpack
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define flavor lua51
%define libmpack_version 1.0.5
Version:        1.0.6
Release:        bp154.1.23
Summary:        Implementation of MessagePack for Lua 5.1
License:        MIT
Group:          Development/Libraries/Other
Url:            https://github.com/libmpack/libmpack-lua
Source:         https://github.com/libmpack/libmpack-lua/archive/%{version}.tar.gz
# libmpack source is necessary to build lua-mpack, next release should build
# fine against system version
# The latest source can be downloaded from: https://github.com/libmpack/libmpack
Source1:        https://github.com/libmpack/libmpack/archive/%{libmpack_version}/libmpack-%{libmpack_version}.tar.gz
# PATCH-FIX-UPSTREAM lua51-mpack-fix-gcc7.patch gh#libmpack/libmpack-lua#3 -- Fix compilation error when using GCC7.
Patch0:         lua51-mpack-fix-gcc7.patch
# PATCH-FIX-UPSTREAM lua51-mpack-fix-compilation.patch gh#libmpack/libmpack-lua#2 -- Fix compilation error when using `USE_SYSTEM_LUA=1`.
Patch1:         lua51-mpack-fix-compilation.patch
BuildRequires:  %{flavor}-devel
BuildRequires:  gcc
BuildRequires:  libtool
Requires:       %{flavor}
%if "%{flavor}" == ""
Name:           lua-mpack
ExclusiveArch:  do_not_build
%else
Name:           %{flavor}-mpack
%endif

%description
mpack is a binary serialization/RPC library that implements both the msgpack
and msgpack-rpc specifications.

%prep
%setup -q -n libmpack-lua-%{version}
%patch0 -p1
%patch1 -p1

# Extract the libmpack source to the right directory.
mkdir -p mpack-src
pushd mpack-src
cp %{SOURCE1} ./
tar --strip-components=1 -xzf libmpack-%{libmpack_version}.tar.gz
popd

# Fix lua directory.
sed -i 's|LUA_CMOD_INSTALLDIR :=.*|LUA_CMOD_INSTALLDIR := $(shell echo "%{lua_archdir}")|g' Makefile

%build
make %{?_smp_mflags} \
    USE_SYSTEM_LUA=yes \
    MPACK_LUA_VERSION=%{lua_version} \
    CFLAGS="%{optflags} -fPIC"

%install
%make_install USE_SYSTEM_LUA=yes

%files
%doc mpack-src/LICENSE-MIT README.md
%dir %{lua_archdir}
%{lua_archdir}/*

%changelog
* Mon Oct 30 2017 jmatejek@suse.com
- do not build for Lua 5.2
* Fri Jul 14 2017 tchvatal@suse.com
- Switch to namespaced lua builds
- Specify all options to build for lua52 and lua53
* Tue Jul  4 2017 ronisbr@gmail.com
- Fix compilation in openSUSE Leap 42.3.
* Thu Jun  1 2017 ronisbr@gmail.com
- Run spec-cleaner.
- Version bump to 1.0.6.
  Upstream changelog:
  Version 1.0.6
  =============
  * It seems luarocks.orgs caches a previously uploaded rockspec
    for a version, even if we explicitly delete the version.
  Version 1.0.5
  =============
  * Bump and adapt build scripts for repository transfer.
- Adapt .spec because the upstream repository changed.
  * libmpack was split into libmpack and libmpack-lua. Hence, now
    we need to download libmpack source code and unpack it into the
    folder mpack-src to build libmapck-lua. Thus, the file
    `libmpack-1.0.5.tar.gz` that contains libmpack v1.0.5 source
    code was added.
- Add patch `lua51-mpack-fix-compilation.patch` to fix a
  compilation problem when using `USE_SYSTEM_LUA=1`. For more
  information, see gh#libmpack/libmpack-lua#2 .
- Add patch `lua51-mpack-fix-gcc7.patch` to fix a compilation
  failure when using GCC7. For more information, see
  gh#libmpack/libmpack-lua#3 .
* Sat Oct  8 2016 ronisbr@gmail.com
- Version bump to 1.0.3.
  * No changelog available.
* Fri Apr 22 2016 ronisbr@gmail.com
- Initial version.
